@@ -3,8 +3,10 @@ from procuret.ancillary.communication_option import CommunicationOption
 from procuret.instalment_link import InstalmentLink, InstalmentLinkOpen
 from procuret.instalment_link import InstalmentLinkOrderBy
 from procuret.data.order import Order
+from procuret.human.headline import HumanHeadline
 from procuret.ancillary.entity_headline import EntityHeadline
 from procuret import errors
 from procuret.version import VERSION
 from procuret.term_rate.term_rate import TermRate
 from procuret.term_rate.group import TermRateGroup
+from procuret.integrate.xero import XeroOrganisation, XeroEntityMap
