@@ -10,3 +10,6 @@ class Perspective(Enum):
     SUPPLIER = 1
     BUSINESS = 2
     ADMINISTRATOR = 3
+    SALES = 4
+    TREASURY = 5
+    INVESTOR = 6
